{% load i18n %}
{% if multimedia_item.picture %}
<a rel="prettyPhoto" href='{{multimedia_item.picture.url}}' ><img class='media-img' alt="{{multimedia_item.name}}" src='{{multimedia_item.thumbnailfile.url}}'/></a>{% endif %}
{% if multimedia_item.url %}

{% if multimedia_item.multimedia_type.iframe %}
<iframe class='media-video video' src='{{multimedia_item.url}}'>
</iframe>
{% else %}
{% ifequal multimedia_item.multimedia_type.media_type 'I' %}
<img class='media-img' alt="{{multimedia_item.name}}" src='{{multimedia_item.url}}'/>
{% else %}
<div class="media-player">
    <span class="media-label">{{multimedia_item.name}}</span>
    <{% ifequal multimedia_item.multimedia_type.media_type 'A' %}audio poster="{{STATIC_URL}}chimere/img/8thNote.png"{% else %}video{% endifequal %} preload="none" controls="controls">
        <source src="{{multimedia_item.url}}" type="{{multimedia_item.multimedia_type.mime_type}}" />
        <div class="fallback">
            <div class="fallback-text">
                <p>{% trans "Please use a modern browser or install the non free Flash-Plugin."%}</p>
                <ul>
                    <li><a class="source" href="{{multimedia_item.url}}">{{multimedia_item.name}}</a></li>
                </ul>
            </div>
        </div>
    </{% ifequal multimedia_item.multimedia_type.media_type 'A' %}audio{% else %}video{% endifequal %}>
</div>
{% endifequal %}
{% endif %}
{% endif %}
{% if multimedia_item.name %}<p class='legend'><strong>{{multimedia_item.name}}</strong></p>{% endif %}
