{% load i18n %}
    <div class='edit' id='submited-window'>
        <p>{% trans "Your new proposition/modification has been submited. A moderator will treat your submission shortly. Thanks!" %}</p>
    </div>
    <script type='text/javascript'>
        $(function(){
            $("#submited-window").dialog({
                    title:"{% trans "Thank you" %}",
                    modal: true,
                    zIndex: 2002,
                    buttons:{
                        "{% trans "Add a new item" %}":
                            function() {
                                window.location = "{{edit_url}}";
                            },
                        "{% trans "Continue edition of this item" %}":
                            function() {
                                $(this).dialog("close");
                            },
                        "{% trans "Return to the map" %}":
                            function() {
                                window.location = "{{index_url}}";
                            }
                        }
                    });
        });
    </script>
