{% load i18n %}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
    <title>{% block title %}Chimère{% endblock %}</title>
</head>
<body>
<div id='content'>
<h2>{% trans "Page not found" %}</h2>
</div>
</body>
</html>
