{% extends "admin/change_form.html" %}
{% load i18n %}
{% block after_field_sets %}
<p class='errornote'>
{% trans "After add/modification of property models you'll have to reload the webserver." %}
</p>
{% endblock %}
