* {
    margin: 0;
    padding: 0;
}
hr {
	clear: both;
}
audio[controls],
video {
	display: block;
}

/* always define a default */
audio {
	width: 328px;
	height: 45px;
}
video {
	width: 510px;
	height: 280px;
}
body {
	position: relative; 
    font: 100.1% arial, helvetica, sans-serif;
	max-width: 1200px;
	width: 800px;
	min-width: 60em;
	margin: auto;
    color: #000;
	background: #fff;
}

code {
	display: block;
	margin: 0 0 10px;
	white-space: pre;
}
.demo-themeswitcher {
	float: right;
}
h1 {
	margin: 20px 0;
	font-size: 180%;
}
h2 {
	margin: 20px 0 10px;
	font-size: 140%;
}
h3 {
	margin: 15px 0 5px;
	font-size: 120%;
}
h4 {
	margin: 15px 0 5px;
	font-size: 100%;
}
ul {
	margin: 10px 0 10px 20px;
}
p {
	margin: 10px 0;
}
