<script class="jwPlayer" type="application/swf" src="{{STATIC_URL}}jme/packages/player.swf"></script>
<script src="{{STATIC_URL}}jme/packages/mm.full.min.js"></script>
<script src="{{STATIC_URL}}jme/utils/jmeEmbedControls.js"></script>
<link rel="stylesheet" href="{{STATIC_URL}}jme/css/player-controls.css" />
<!-- a11y-slider -->
<script src="{{STATIC_URL}}jme/utils/a11y-slider.ext.js"></script>
<!-- workaround for flash bug in ie -->
<script src="{{STATIC_URL}}jme/utils/reinitjme.js"></script>
<!-- fullwindow plugin -->
<script class="jme-jwPlayer" type="application/swf" src="{{STATIC_URL}}jme/packages/jmefs.swf"></script>
<script src="{{STATIC_URL}}jme/plugins/fullwindow.js"></script>
<!-- useractivity -->
<script src="{{STATIC_URL}}jme/utils/useractivity.js"></script>

<!-- prettyPhoto not jme but media -->
<link rel="stylesheet" href="{{STATIC_URL}}prettyPhoto/css/prettyPhoto.css" />
<script type="text/javascript" src="{{STATIC_URL}}prettyPhoto/js/jquery.prettyPhoto.js"></script>
