{% extends "base.html" %}
{% load chimere_tags i18n %}
{% block extra_head %}
<link rel="stylesheet" href="{{ STATIC_URL }}chimere/css/styles.css" />
{% if css_area %}
<link rel="stylesheet" href="{{ css_area }}" />{% endif %}
{% endblock %}
{% block header %}
<noscript>
    <div id="no-js-message">
        <p id='no-js' class='warning'>{% trans "You must enable JavaScript in your browser to display Chimère."%}</p>
    </div>
</noscript>
    {% block page_title %}
        {% include "chimere/blocks/page_title.html" %}
    {% endblock %}
    {% block actions %}
        {% include "chimere/blocks/actions.html" %}
    {% endblock %}
{% endblock %}
{% block content %}
    {% block top %}{% endblock %}
    {% block message_map %}{% endblock %}
    {% block message_edit %}{% endblock %}
    {% block bottom %}{% endblock %}
{% endblock %}
{% block footer %}
    {% include "chimere/blocks/footer.html" %}
{% endblock %}

