.bsmListSortableCustom li {
  cursor: move;
  border-radius: 5px;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  margin: 2px 0;
}

.bsmList-custom {
  /* html list that contains selected items */
  margin: 0.25em 0 0.25em 0;
  display: block;
  padding-left: 0;
  list-style: none;
}

.bsmListItem-custom {
  /* li item from the html list above */
  margin: 0 5px 5px 0;
  padding: 4px;
  list-style: none;
  background: #ddd;
  border: 1px solid #bbb;
  line-height: 1em;
  float: left;
  border-radius: 5px;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px; 
}

.bsmListItem-custom:hover {
  background-color: #e5e5e5;
  box-shadow: 0 0 3px #aaa;
  -webkit-box-shadow: 0 0 3px #aaa;
  -moz-box-shadow: 0 0 3px #aaa;
}

.bsmListItemLabel-custom {
  padding-right: 5px;
}

.bsmListItemRemove-custom {
  text-decoration: none;
}

