{% for css_url in JQUERY_CSS_URLS %}
<link rel="stylesheet" href="{{ css_url }}" />{% endfor %}

{% for js_url in JQUERY_JS_URLS %}
<script type="text/javascript" src="{{ js_url }}"></script>{% endfor %}
