{% extends "chimere/base.html" %}
{% load i18n chimere_tags %}
{% block extra_head %}
    {{ block.super }}
    {{ form.media }}
    {% head_jquery %}
{% endblock %}
{% block message_map %}{% endblock %}
{% block message_edit%}{% endblock %}
{% block content %}
    {{ block.super }}
    {% if message %}
        <div class='warning'><p>{{message}}</p></div>
    {% else %}
        <fieldset class='edit'>
            <p>{% trans "If you have some requests or remarks about this site you can leave them here." %}</p>
            <form action="." method="post">
            {{contact_form.as_p}}
            <input type="submit" value="{% trans "Submit" %}" />
            </form>
        </fieldset>
    {% endif %}
{% endblock %}

