{% extends "admin/base_site.html" %}
{% load chimere_tags i18n admin_static %}

{% block extrahead %}
<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />
{% endblock %}


{% block content %}
<fieldset class='module'>
<form method='POST' action='.'>
{% csrf_token %}
<input type='hidden' name='action' value='export_to_osm'/>
<input type='hidden' name='validate' value='1'/>
<input type='hidden' name='_selected_action' value='{{item.pk}}'/>
<table>
{{ form.as_table }}
</table>
</fieldset>
<ul class='messagelist'>
    <li>{% trans "Only points of interest are managed by this export." %}</li>
    <li>{{msg_item}}</li>
    <li>{% trans "Before exporting to OSM an import is done to verify that no modification has been made. All pending imported item have to be validated before export." %}</li>
</ul>
<p class='errornote'>{% blocktrans %}Ensure that all the data exported to OSM have an appropriate license. You can exclude some points of interest by checking the checkbox "Not to be imported in OSM" in the point of interest form. <strong>If you are not sure of what you are doing: DON'T EXPORT TO OSM</strong>!{% endblocktrans %}</p>
<div class='submit-row'>
<p class='deletelink-box'><a href="{% if item.point %}{% url admin:chimere_marker_changelist %}{%else%}{% url admin:chimere_route_changelist %}{%endif%}">{% trans "Back to list" %}</a></p>
<input class='default' type='submit' value='{% trans "Export to OSM" %}'/>
</div>
</form>
{% endblock %}
