.gallery iframe{
    width: 432px;
    height: 315px;
}

video {
    display: block;
    width: 432px;
    height: 240px;
}

.media-player {
    position: relative;
    width: 432px;
    min-height:30px;
}
/*
 * escaped for development mode

.media-controls {
    display: none;
}
.js-on .media-controls {
    display: block;
}

 */
.media-controls {
    height: 2em;
    zoom: 1;
    position: relative;
    margin: 0;
    padding: 0 210px 0 85px;
    z-index: 9; /* IE opacity: bug */
}
/* Poster Display Style */
.media-player img.poster-display { 
    display: block; 
    position: absolute; 
    left: 0; 
    top: 0; 
    width: 100%; 
    height: 100%; 
    margin: 0; 
    padding: 0; 
    cursor: pointer; 
}
.media-controls a.ui-state-default {
    position: absolute;
    top: .32em;
    padding: 2px;
    overflow: hidden;
}
.media-controls a:focus {
    outline: 1px dotted #666;
}
a.ui-state-default .button-text {
    position: absolute;
    display: block;
    left: -9999px;
    width: 3px;
}
.media-controls a.play-pause {
    left: 5px;
}
.timeline-slider {
    top: .5em;
    right: 8px;
}
.media-controls a.ui-slider-handle {
    padding: 0;
    top: -0.26em;
}
.media-controls a.mute-unmute {
    right: 143px;
}
.player-display {
    overflow: hidden;
    position: absolute;
    top: 9px;
    width: 35px;
    font-size: 12px;
    text-align: center;
}
.duration {
    right: 168px;
}
.current-time {
    left: 30px;
}
div.volume-slider {
    position: absolute;
    top: .5em;
    right: 42px;
    width: 90px;
}
.media-controls .ui-progressbar {
    height: 0.8em;
}

.handle-label,
span.media-label,
.js-on .player-errors {
    display: none;
}
.media-role {
    position: absolute;
    left: -9999px;
    display: block;
    width: 1px;
}
.video-box {
    position: relative;
    width: 100%;
}
.media-state {
    position: absolute;
    /* don't let overlay video for flash unblock */
    display: none;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    cursor: pointer;
    background: url(../css-img/loader.gif) -9000px -9000px no-repeat;
}
.idle .media-state {
    display: block;
    background: url(../css-img/play-icon.png) center no-repeat;
}
.waiting .media-state {
    display: block;
    background: url(../css-img/loader.gif) center no-repeat;
}

/* on totalerror, flashblocker or showFallback: true */
.totalerror .media-controls {
    display: none !important;
}

.flashblocker .media-element-box {
    min-width: 40px;
    min-height: 40px;
} 

/*
 * fullscreen plugin
 */

.wraps-fullscreen .media-state {
    z-index: 99999;
}
.wraps-fullscreen .media-controls-wrapper {
    z-index: 999999;
    position: absolute;
    width: 100%;
    bottom: 10px;
}

/*
 * playlist example (audioplayer.html)
 */
.playlist {
    margin: 5px 0 0;
    padding: 5px;
    list-style: none;
}
.playlist ul {
    margin: 0;
    list-style: none;
}

.playlist li {
    margin: 2px 0;
    padding: 2px 5px;
    cursor: pointer;
}
.playlist a {
    overflow: hidden;
    zoom: 1;
    display: block;
    outline: none;
}
.playlist img {
    float: left;
    display: block;
    margin: 1px 4px 1px 0;
}
.playlist a:focus,
.playlist a:active {
    text-decoration: underline !important;
}
