{% extends "chimere/main_map.html" %}
{% load i18n %}
{% block body_class %}class='simple'{% endblock %}
{% block body_id %}id='simple'{% endblock %}
{% block menu %}{# no menu in simple mode #}{% endblock %}
{% block message_edit %}{% endblock %}
{% block sidebar %}
    <div id='panel'>
        <a href='#' onclick='showHide("categories")'>
            <h2>{% trans "Categories"%}</h2>
        </a>
        <form method='post' name='frm_categories' id='frm_categories'>
        <div id='categories' name='categories'></div>
        </form>
    </div>
{% endblock %}
{% block content %}
    <script type='text/javascript'><!--
        var simple = true;
    // --></script>
    {{ block.super }}
{% endblock %}
