{% extends "admin/change_form.html" %}
{% load i18n %}
{% block field_sets %}
{% if original.has_modified %}
<p class='errornote'>
{% url admin:admin-modification object_id as rapprochement_form %}
{% blocktrans %}
This item has a reference item associated to it. You should treat it via the <a href='{{ rapprochement_form }}'>rapprochement form</a>.
{% endblocktrans %}
</p>
{% endif %}
{{ block.super }}
{% endblock %}
