{% extends "chimere/base.html" %}
{% load i18n unlocalize_point chimere_tags %}
{% block extra_head %}
{% head_jquery %}
{% head_chimere %}
{% head_jme %}
<script src="{{ STATIC_URL }}chimere/js/jquery.chimere.js"></script>
{{ block.super }}
{% endblock %}
{% block message_edit %}{% endblock %}
{% block sidebar %}
    <div id='panel' class='draggable ui-widget ui-corner-all'>
        <h2 class='ui-widget ui-state-default ui-corner-all ui-widget-header'>{% trans "Categories"%}</h2>
        <form method='post' name='frm_categories' id='frm_categories'>
            <div id='categories'>
            {# Categories are displayed in JS #}
            </div>
        </form>
    </div>

    <div id='utils-div' class='ui-widget ui-state-default ui-corner-all'>
    {% if areas_visible %}
        {% display_areas %}
    {% endif %}
        {% display_news news_visible %}
        <div id='permalink' class='ui-widget ui-button ui-state-default ui-corner-all'></div>
        <a id='simple_button' class='ui-widget ui-button ui-state-default ui-corner-all' href='{% url chimere:simple_index area_name_slash %}'>{% trans "Simple map" %}</a>
    </div>
    <div id='detail' class='ui-widget ui-corner-all'></div>
    <div id='category_detail'></div>
{% endblock %}
{% block content %}
    {{block.super}}
    {% map 'main-map' %}
{% endblock %}
{% block footer %}
    <p class='map-footer'>{% include "chimere/blocks/footer.html" %}</p>
{% endblock %}
