{% for css_url in OSM_CSS_URLS %}
<link rel="stylesheet" href="{{ css_url }}" />{% endfor %}
{% for js_url in OSM_JS_URLS %}
<script src="{{ js_url }}"></script>{% endfor %}
<script src="{{ STATIC_URL }}chimere/js/jquery.chimere.js"></script>
<script type="text/javascript">
    /* Global variables */
    var STATIC_URL = static_url = "{{ STATIC_URL }}";
    var MEDIA_URL = media_path = "{{ MEDIA_URL }}";
    var extra_url = "{{ EXTRA_URL }}";
</script>
<script src="{{ STATIC_URL }}chimere/js/utils.js"></script>
<script src="{{ STATIC_URL }}chimere/js/base.js"></script>
<script type="text/javascript">
    var DEFAULT_ZOOM = {{ DEFAULT_ZOOM }};
    var EPSG_DISPLAY_PROJECTION = epsg_display_projection = new OpenLayers.Projection('EPSG:{{ EPSG_DISPLAY_PROJECTION }}');
    OpenLayers.ImgPath = '{{ STATIC_URL }}chimere/img/';
    var EPSG_PROJECTION = epsg_projection = new OpenLayers.Projection('EPSG:{{ EPSG_PROJECTION }}');
    var CENTER_LONLAT = centerLonLat = new OpenLayers.LonLat{{ DEFAULT_CENTER }}.transform(epsg_display_projection, epsg_projection);
    /*var map_layer = {{ MAP_LAYER|safe }};*/
    var restricted_extent;
    {% if area_name %}
    var area_name = '{{ area_name }}';{% endif %}

    $(function() {$( ".draggable" ).draggable({handle:"h2"});});
</script>
<style>
.olControlPanPanel div {
    background-image: url({{STATIC_URL}}chimere/img/pan-panel.png);
}

.olControlZoomPanel div {
    background-image: url({{STATIC_URL}}chimere/img/zoom-panel.png);
}
</style>



