{% load i18n unlocalize_point %}
{% if areas %}
    <div id='areas'>
        <h2>{% trans "Shortcuts"%}</h2>
        <ul>
            {% for area in areas %}
                <li><img class="zoom_image" alt="{% trans 'Zoom to' %} {{area.name}}" src="{{ STATIC_URL }}chimere/img/zoom.png" onclick="$('#maps').chimere('zoom', {'area': [{{area.upper_left_corner.x|unlocalize_point}}, {{area.upper_left_corner.y|unlocalize_point}}, {{area.lower_right_corner.x|unlocalize_point }}, {{area.lower_right_corner.y|unlocalize_point}}]});" /> {{area.name}}</li>
            {% endfor %}
        </ul>
    </div>
{% endif %}
